@@ -4,16 +4,16 @@ product_list <- 'box(
   status = "primary",
   productList(
     productListItem(
-      src = "https://image.darty.com/hifi_video/televiseurs-led/grand_ecran_led/samsung_ue55mu9005_4k_uhd_s1703224306074A_140323143.jpg", 
+      src = "https://www.pngmart.com/files/1/Haier-TV-PNG.png", 
       productTitle = "Samsung TV", 
       productPrice = "$1800", 
       priceColor = "warning",
       "This is an amazing TV, but I do not like TV!"
     ),
     productListItem(
-      src = "http://icon-park.com/imagefiles/imac.png", 
+      src = "https://upload.wikimedia.org/wikipedia/commons/7/77/IMac_Pro.svg", 
       productTitle = "Imac 27", 
-      productPrice = "$2400", 
+      productPrice = "$4999", 
       priceColor = "danger",
       "This is were I spend most of my time!"
     )
