@@ -3,11 +3,11 @@ social_buttons <- 'box(
   title = "Social Buttons",
   status = NULL,
   socialButton(
-    url = "http://dropbox.com",
+    url = "https://dropbox.com",
     type = "dropbox"
   ),
   socialButton(
-    url = "http://github.com",
+    url = "https://github.com",
     type = "github"
   )
 )'
\ No newline at end of file
